bgen_metafile
-------------

.. currentmodule:: cbgen

.. autosummary::

    bgen_metafile
    bgen_metafile.close
    bgen_metafile.filepath
    bgen_metafile.npartitions
    bgen_metafile.nvariants
    bgen_metafile.partition_size
    bgen_metafile.read_partition

.. autoclass:: bgen_metafile
   :members:
   :inherited-members:
